mvregress: mvregress

Description Usage Arguments Examples

View source: R/mvregress.R

Description

Performs multivariate normal regression for one to several response variables and one to several covariate variables.

Usage

1
mvregress(X, Y, ...)

Arguments

X

matrix of covariates with each column representing a variable, and each row representing an observation

Y

matrix of response variables with each column representing a variable, and each row representing an observation

...

extra parameters passed to lm(Y~X, ...)

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
y1 = seq(0.1,1,0.1)
y2 = y1*y1+1

Y = cbind(y1,y2)

x1 = log(1:10)
x2 = x1^2-x1
X = cbind(x1,x2)
 
m = mvregress(X,Y)

mrparker909/mvregress documentation built on Dec. 27, 2019, 3:40 p.m.