Description Usage Arguments Examples
View source: R/likelihoodRatioTest.R
Calculates the likelihood ratio test statistic and associated p-value under the chi squared approximation with degrees of freedom df.
1 | likelihoodRatioTest(logLik_H0, logLik_H1, df)
|
logLik_H0 |
log likelihood of the null model |
logLik_H1 |
log likelihood of the alternative model |
df |
degrees of freedom for the chisquared random variable (usually the difference in degrees of freedom between the alternative and the null models) |
1 2 3 4 5 6 7 8 9 10 11 12 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.