Description Usage Arguments Examples
Performs multivariate normal regression for one to several response variables and one to several covariate variables.
1 |
X |
matrix of covariates with each column representing a variable, and each row representing an observation |
Y |
matrix of response variables with each column representing a variable, and each row representing an observation |
... |
extra parameters passed to lm(Y~X, ...) |
1 2 3 4 5 6 7 8 9 10 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.